# nex-Python-package
Python package for running NeuroExplorer Python scripts an any IDE

## Description

Provides a simple way to run Python scripts that control [NeuroExplorer](https://www.neuroexplorer.com) (open data file, get file data, run analysis, save results, etc.) in any Python IDE.

The package also provides classes to read and write .nex and .nex5 data files.

See [NeuroExplorer Python Scripting Documentation](https://www.neuroexplorer.com/docs/reference/scripting/index.html) for detailed information about Python scripting in NeuroExplorer.

To install package, run `pip install nex`.
